@@ -35,8 +35,9 @@ class DBConnect():
             new_data = self.mongo_collection.insert_one(docu)
             return new_data.inserted_id
         except Exception as err:
-            logging.warning('MongoDB(组件)出现写入错误: {0}'.format(err))
-            return False
+            str_data = 'MongoDB(组件)出现写入错误: {0}'.format(err)
+            logging.warning(str_data)
+            abort(Response(str_data, 500, {}))
 
     def does_it_exist(self, docu: dict) -> bool:
         count = self.mongo_collection.count_documents(docu)
@@ -53,8 +54,9 @@ class DBConnect():
                 self.mongo_collection.update_one(find_docu, modify_docu)
             return True
         except Exception as err:
-            logging.warning('MongoDB(组件)出现更新错误: {0}'.format(err))
-            return False
+            str_data = 'MongoDB(组件)出现更新错误: {0}'.format(err)
+            logging.warning(str_data)
+            abort(Response(str_data, 500, {}))
 
     def find_paging(self, parameter: Parameter) -> tuple:
         parameter.verification(
@@ -83,8 +85,9 @@ class DBConnect():
             if len(columns) != len(sort_order) or len(columns) != len(filtered_value):
                 raise Exception('三个控制列表的长度不一致')
         except Exception as err:
-            logging.warning('计算组件分页参数异常: {0}'.format(err))
-            abort(Response(str(err), 400, {}))
+            str_data = '计算组件分页参数异常: {0}'.format(err)
+            logging.warning(str_data)
+            abort(Response(str_data, 400, {}))
         # 查找字典和排序列表
         find_dict = {}
         sort_list = []
