@@ -16,7 +16,7 @@ def handle_date(date: str, date_type='start') -> datetime:
             date_data = datetime.fromtimestamp(int(date_time))
         else:
             date_data = datetime.strptime(date, "%Y-%m-%d")
-        if date_type == 'end':
+        if date_type == 'end' and date_data:
             date_data += timedelta(hours=23, minutes=59, seconds=59)
     except Exception as err:
         date_data = None
